summaryrefslogtreecommitdiff
path: root/var/spack/repos/builtin/packages/py-matplotlib/freetype-include-path.patch
blob: 7007c88d0dbfd91164c0773eb8222da7b773dbd3 (plain) (blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
diff --git a/setupext.py b/setupext.py
index 6d363012eb4..00ef3fe5a3d 100644
--- a/setupext.py
+++ b/setupext.py
@@ -162,8 +162,10 @@ def get_include_dirs():
     """
     include_dirs = [os.path.join(d, 'include') for d in get_base_dirs()]
     if sys.platform != 'win32':
         # gcc includes this dir automatically, so also look for headers in
         # these dirs
+        include_dirs.extend(
+            os.environ.get('CPATH', '').split(os.pathsep))
         include_dirs.extend(
             os.environ.get('CPLUS_INCLUDE_PATH', '').split(os.pathsep))
     return include_dirs
@@ -162,8 +162,10 @@ def get_include_dirs():
     include_dirs = [os.path.join(d, 'include') for d in get_base_dirs()]
     if sys.platform != 'win32':
-        # gcc includes this dir automatically, so also look for headers in
+        # gcc includes these dirs automatically, so also look for headers in
         # these dirs